AudioControl = {}

local function OnInitialize(self, addOnName)
  
--  Check, if this is the right add-on
	if addOnName ~= "AudioControl" then  
		return
	end
  
	local SetTranslation = ZO_CreateStringId
	local __Localization = AudioControl.Localization
  
--  Get translated texts
	local __MenuToggleMasterVolumeText  = __Localization.Translate(__Localization.MENU_TOGGLE_VOLUME_MASTER)
	local __MenuToggleMusicVolumeText   = __Localization.Translate(__Localization.MENU_TOGGLE_VOLUME_MUSIC)
	local __MenuToggleAmbientVolumeText = __Localization.Translate(__Localization.MENU_TOGGLE_VOLUME_AMBIENT)
	local __MenuToggleEffectsVolumeText = __Localization.Translate(__Localization.MENU_TOGGLE_VOLUME_EFFECTS)
	local __MenuToggleStepsVolumeText   = __Localization.Translate(__Localization.MENU_TOGGLE_VOLUME_STEPS)
	local __MenuToggleDialogVolumeText  = __Localization.Translate(__Localization.MENU_TOGGLE_VOLUME_DIALOG)
	local __MenuToggleUIVolumeText      = __Localization.Translate(__Localization.MENU_TOGGLE_VOLUME_UI)
  
--  Set menu texts
	SetTranslation("SI_BINDING_NAME_TOGGLE_VOLUME_MASTER",  __MenuToggleMasterVolumeText)
	SetTranslation("SI_BINDING_NAME_TOGGLE_VOLUME_MUSIC",   __MenuToggleMusicVolumeText)
	SetTranslation("SI_BINDING_NAME_TOGGLE_VOLUME_AMBIENT", __MenuToggleAmbientVolumeText)
	SetTranslation("SI_BINDING_NAME_TOGGLE_VOLUME_EFFECTS", __MenuToggleEffectsVolumeText)
	SetTranslation("SI_BINDING_NAME_TOGGLE_VOLUME_STEPS",   __MenuToggleStepsVolumeText)
	SetTranslation("SI_BINDING_NAME_TOGGLE_VOLUME_DIALOG",  __MenuToggleDialogVolumeText)
	SetTranslation("SI_BINDING_NAME_TOGGLE_VOLUME_UI",      __MenuToggleUIVolumeText)

--  Load Libraries
	AudioControl.Console	   = Console()
	AudioControl.Settings	   = Storage()
	
--  Load Classes
	AudioControl.AudioType     = AudioType()
	AudioControl.AudioSettings = AudioSettings()
  
end

local function OnPlayerActivated()
    AudioControl.Console:Initialize()
end

-- Toggle master volume
function ToggleMasterVolume()

	local __Audio		 = AudioControl.AudioSettings:Master()
	local __Localization = AudioControl.Localization
	
	__Audio:ToggleMute()
	LogVolumeStatus(__Audio, __Localization.Translate(__Localization.STATUS_VOLUME_MASTER))
 
end
 
-- Toggle music
function ToggleMusicVolume()

    local __Audio		 = AudioControl.AudioSettings:Music()
	local __Localization = AudioControl.Localization
	
	__Audio:ToggleMute()
	LogVolumeStatus(__Audio, __Localization.Translate(__Localization.STATUS_VOLUME_MUSIC))
 
end
 
-- Toggle ambient
function ToggleAmbientVolume()

    local __Audio		 = AudioControl.AudioSettings:Ambient()
	local __Localization = AudioControl.Localization
	
	__Audio:ToggleMute()
	LogVolumeStatus(__Audio, __Localization.Translate(__Localization.STATUS_VOLUME_AMBIENT))
 
end
 
-- Toggle effects
function ToggleEffectsVolume()

    local __Audio		 = AudioControl.AudioSettings:Effects()
	local __Localization = AudioControl.Localization
	
	__Audio:ToggleMute()    
    LogVolumeStatus(__Audio, __Localization.Translate(__Localization.STATUS_VOLUME_EFFECTS))
 
end
 
-- Toggle steps
function ToggleStepsVolume()

    local __Audio		 = AudioControl.AudioSettings:Steps()
	local __Localization = AudioControl.Localization
	
	__Audio:ToggleMute()
	LogVolumeStatus(__Audio, __Localization.Translate(__Localization.STATUS_VOLUME_STEPS))
 
end

-- Toggle dialogs
function ToggleDialogVolume()

    local __Audio		 = AudioControl.AudioSettings:Dialog()
	local __Localization = AudioControl.Localization
	
	__Audio:ToggleMute()
	LogVolumeStatus(__Audio, __Localization.Translate(__Localization.STATUS_VOLUME_DIALOG))
 
end
 
function ToggleUIVolume()

    local __Audio		 = AudioControl.AudioSettings:UI()
	local __Localization = AudioControl.Localization
	
	__Audio:ToggleMute()
	LogVolumeStatus(__Audio, __Localization.Translate(__Localization.STATUS_VOLUME_UI))
 
end

-- Send user feedback of what is going on
function LogVolumeStatus(audio, text)
    
    local __Localization = AudioControl.Localization
    local __Status = "switched"
    local __Color = Colors.Default()
    
    if audio:IsMuted() then
        __Status = __Localization.Translate(__Localization.STATUS_TURNED_OFF)
        __Color = Colors.Red()
    else
        __Status = __Localization.Translate(__Localization.STATUS_TURNED_ON)        
        __Color = Colors.Green()
    end
    
    local __Message = Message()
    
    __Message:Append(text)
    __Message:Append(": ")
    __Message:Append(__Status, __Color)

    AudioControl.Console:WriteLine(__Message)
        
end

-- Slash commands
SLASH_COMMANDS["/mute"] = ToggleMasterVolume
SLASH_COMMANDS["/mu"]   = ToggleMasterVolume
SLASH_COMMANDS["/m"]    = ToggleMasterVolume
SLASH_COMMANDS["/rl"]   = function() ReloadUI("ingame") end

EVENT_MANAGER:RegisterForEvent("AudioControl", EVENT_ADD_ON_LOADED, 	OnInitialize)
EVENT_MANAGER:RegisterForEvent("AudioControl", EVENT_PLAYER_ACTIVATED, 	OnPlayerActivated)
